@@ -261,6 +261,29 @@ Q_DECLARE_LOGGING_CATEGORY(QT_OPCUA)
     \a statusCode contains the result of the operation.
 */
 
+/*!
+    \fn void QOpcUaClient::registerNodesFinished(const QStringList &nodesToRegister, const QStringList &registeredNodeIds, QOpcUa::UaStatusCode statusCode)
+    \since 6.7
+
+    This signal is emitted after a \l registerNodes() operation has finished.
+    \a nodesToRegister contains the node ids from the request for correlation purposes.
+    The node ids returned by the server are in \a registeredNodeIds and have the same ordering as the ids in the request.
+    \a statusCode indicates if the operation was successful.
+
+    \sa registerNodes()
+*/
+
+/*!
+    \fn void QOpcUaClient::unregisterNodesFinished(const QStringList &nodesToUnregister, QOpcUa::UaStatusCode statusCode)
+    \since 6.7
+
+    This signal is emitted after a \l unregisterNodes() operation has finished.
+    \a nodesToUnregister contains the node ids from the request for correlation purposes.
+    \a statusCode indicates if the operation was successful.
+
+    \sa unregisterNodes()
+*/
+
 /*!
     \internal QOpcUaClientImpl is an opaque type (as seen from the public API).
     This prevents users of the public API to use this constructor (even though
@@ -311,6 +334,12 @@ QOpcUaClient::QOpcUaClient(QOpcUaClientImpl *impl, QObject *parent)
 
     QObject::connect(impl, &QOpcUaClientImpl::passwordForPrivateKeyRequired,
                      this, &QOpcUaClient::passwordForPrivateKeyRequired);
+
+    QObject::connect(impl, &QOpcUaClientImpl::registerNodesFinished,
+                     this, &QOpcUaClient::registerNodesFinished);
+
+    QObject::connect(impl, &QOpcUaClientImpl::unregisterNodesFinished,
+                     this, &QOpcUaClient::unregisterNodesFinished);
 }
 
 /*!
@@ -1031,4 +1060,97 @@ QOpcUaHistoryReadResponse *QOpcUaClient::readHistoryData(const QOpcUaHistoryRead
     return d->m_impl->readHistoryData(request);
 }
 
+/*!
+    \since 6.7
+
+    Registers the node ids in \a nodesToRegister on the server and returns \c true if the request
+    has been successfully dispatched.
+    The results are returned in the \l registerNodesFinished() signal.
+
+    The node registration service is used to let the server know that a node will be accessed frequently
+    so it may perform operations like keeping the connection to an external resource open.
+    The server may also return an alias node id which is recommended to be numeric. This might come in
+    handy if a node with a long string identifier node id is used in many requests.
+    The real performance gain (if any) depends on the server's implementation.
+
+    The registered node ids are only guaranteed to be valid for the current session.
+    Any registrations that are no longer needed should be unregistered as soon as possible so the
+    server may free the associated resources.
+
+    \sa unregisterNodes()
+ */
+bool QOpcUaClient::registerNodes(const QStringList &nodesToRegister)
+{
+    Q_D(const QOpcUaClient);
+    return d->m_impl->registerNodes(nodesToRegister);
+}
+
+/*!
+    \since 6.7
+
+    Unregisters the node ids in \a nodesToUnregister on the server and returns \c true if the request
+    has been successfully dispatched.
+    The results are returned in the \l unregisterNodesFinished() signal.
+
+    The node ids to pass in \a nodesToUnregister must have been obtained via \l registerNodes().
+
+    \sa registerNodes()
+ */
+bool QOpcUaClient::unregisterNodes(const QStringList &nodesToUnregister)
+{
+    Q_D(const QOpcUaClient);
+    return d->m_impl->unregisterNodes(nodesToUnregister);
+}
+
+/*!
+    \since 6.7
+
+    Starts a read event history request for one or multiple node ids with the parameters in \a request.
+
+    Returns a \l QOpcUaHistoryReadResponse which contains the state of the request if the asynchronous
+    request has been successfully dispatched. The results are returned in the
+    \l QOpcUaHistoryReadResponse::readHistoryEventsFinished(const QList<QOpcUaHistoryEvent> &results, QOpcUa::UaStatusCode serviceResult)
+    signal.
+
+    The following example retrieves historic events for the last two days for two nodes. Up to 10 events per node are returned at a time.
+    While there are more events matching the filter and the provided time range, \c hasMoreData() will be true and more events can be
+    fetched via \b readMoreData().
+
+    \code
+    QOpcUaMonitoringParameters::EventFilter filter;
+    filter << QOpcUaSimpleAttributeOperand("Message");
+    filter << QOpcUaSimpleAttributeOperand("Time");
+
+    const QOpcUaHistoryReadEventRequest request({ QOpcUaReadItem("ns=2;s=EventHistorian"), QOpcUaReadItem("ns=2;s=EventHistorian2") },
+                                                QDateTime::currentDateTime().addDays(-2), QDateTime::currentDateTime(),
+                                                filter, 10);
+
+    // The response object must be freed by the user after all wanted data has been retrieved
+    const auto response = opcuaClient->readHistoryEvents(request);
+
+    QObject::connect(response, &QOpcUaHistoryReadResponse::readHistoryEventsFinished, this,
+                     [response](const QList<QOpcUaHistoryEvent> &results, QOpcUa::UaStatusCode serviceResult) {
+        if (serviceResult != QOpcUa::UaStatusCode::Good) {
+            qDebug() << "Service call failed with" << serviceResult;
+            return;
+        }
+
+        // Print what we got so far
+        for (const auto &result : response->events()) {
+            qDebug() << "Results for" << result.nodeId() << result.statusCode();
+            for (const auto &event : result.events())
+                qDebug() << "    Event:" << event;
+        }
+
+        if (response->hasMoreData())
+            response->readMoreData();
+    });
+    \endcode
+*/
+QOpcUaHistoryReadResponse *QOpcUaClient::readHistoryEvents(const QOpcUaHistoryReadEventRequest &request)
+{
+    Q_D(const QOpcUaClient);
+    return d->m_impl->readHistoryEvents(request);
+}
+
 QT_END_NAMESPACE
